
#ifndef PDF_UPDATE_CATALOG_H
#define PDF_UPDATE_CATALOG_H

#include "../Page_no/PS_page_numbering.h"
#include "PDF.h"

// ---------------------------------------------------------------------
// To add a PageLabel and a reference to Outlines to the PDF catalog.
// ---------------------------------------------------------------------

namespace PDF {
  std::string update_catalog(
    PDF &pdf,
    const Page_no::PS_page_numbering &nog
  );
  std::string add_title_to_info(
    PDF &pdf,
    const std::string &title
  );
  std::string update_trailer(
    PDF &pdf,
    int n_pdf_obj,
    int offset_xref
  );
}

#endif

